diff --git a/docs/changelog.md b/docs/changelog.md
index 54b23a8ab..eda1c6b7d 100644
--- a/docs/changelog.md
+++ b/docs/changelog.md
@@ -79,6 +79,7 @@ Use past tense when adding new entries; sign your name off when you add or chang
## Upcoming changes
* You know the drill
+* Fix typo in config for IP bans. (@redchess64)
## TShock 5.2.1
* Updated `TSPlayer.GodMode`. (@AgaSpace)
diff --git a/TShockAPI/Configuration/TShockConfig.cs b/TShockAPI/Configuration/TShockConfig.cs
index 79c374b25..c91466fec 100644
--- a/TShockAPI/Configuration/TShockConfig.cs
+++ b/TShockAPI/Configuration/TShockConfig.cs
@@ -320,8 +320,8 @@ public class TShockSettings
[Description("The reason given if banning a mediumcore player on death.")]
public string MediumcoreBanReason = GetString("Death results in a ban");
- /// Disbales IP bans by default, if no arguments are passed to the ban command.
- [Description("Disbales IP bans by default, if no arguments are passed to the ban command.")]
+ /// Disables IP bans by default, if no arguments are passed to the ban command.
+ [Description("Disables IP bans by default, if no arguments are passed to the ban command.")]
public bool DisableDefaultIPBan;
/// Enable or disable the whitelist based on IP addresses in the whitelist.txt file.